# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xce\x01\n\x0eTickRawRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x36\n\x05level\x18\x03 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\"l\n\x0bTickRawItem\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"U\n\x0fTickRawResponse\x12\x42\n\traw_items\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.tick.v1.TickRawItem\"q\n\x10TickRawResponse2\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x32\x86\x01\n\x0eTickRawService\x12t\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse0\x01\x62\x06proto3')



_TICKRAWREQUEST = DESCRIPTOR.message_types_by_name['TickRawRequest']
_TICKRAWITEM = DESCRIPTOR.message_types_by_name['TickRawItem']
_TICKRAWRESPONSE = DESCRIPTOR.message_types_by_name['TickRawResponse']
_TICKRAWRESPONSE2 = DESCRIPTOR.message_types_by_name['TickRawResponse2']
TickRawRequest = _reflection.GeneratedProtocolMessageType('TickRawRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawRequest)
  })
_sym_db.RegisterMessage(TickRawRequest)

TickRawItem = _reflection.GeneratedProtocolMessageType('TickRawItem', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWITEM,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawItem)
  })
_sym_db.RegisterMessage(TickRawItem)

TickRawResponse = _reflection.GeneratedProtocolMessageType('TickRawResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse)
  })
_sym_db.RegisterMessage(TickRawResponse)

TickRawResponse2 = _reflection.GeneratedProtocolMessageType('TickRawResponse2', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE2,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse2)
  })
_sym_db.RegisterMessage(TickRawResponse2)

_TICKRAWSERVICE = DESCRIPTOR.services_by_name['TickRawService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKRAWREQUEST._serialized_start=272
  _TICKRAWREQUEST._serialized_end=478
  _TICKRAWITEM._serialized_start=480
  _TICKRAWITEM._serialized_end=588
  _TICKRAWRESPONSE._serialized_start=590
  _TICKRAWRESPONSE._serialized_end=675
  _TICKRAWRESPONSE2._serialized_start=677
  _TICKRAWRESPONSE2._serialized_end=790
  _TICKRAWSERVICE._serialized_start=793
  _TICKRAWSERVICE._serialized_end=927
# @@protoc_insertion_point(module_scope)
