# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_book_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/type/shared/v1/market_book_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"m\n\x11MarketBookUpdates\x12\x13\n\x0bis_snapshot\x18\x01 \x01(\x08\x12\x43\n\x07updates\x18\x02 \x03(\x0b\x32\x32.systemathics.apis.type.shared.v1.MarketBookUpdate\"\xe9\x01\n\x10MarketBookUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x34\n\x04side\x18\x02 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.Side\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\x12)\n\x04size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x05price\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueb\x06proto3')



_MARKETBOOKUPDATES = DESCRIPTOR.message_types_by_name['MarketBookUpdates']
_MARKETBOOKUPDATE = DESCRIPTOR.message_types_by_name['MarketBookUpdate']
MarketBookUpdates = _reflection.GeneratedProtocolMessageType('MarketBookUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdates)
  })
_sym_db.RegisterMessage(MarketBookUpdates)

MarketBookUpdate = _reflection.GeneratedProtocolMessageType('MarketBookUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdate)
  })
_sym_db.RegisterMessage(MarketBookUpdate)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MARKETBOOKUPDATES._serialized_start=220
  _MARKETBOOKUPDATES._serialized_end=329
  _MARKETBOOKUPDATE._serialized_start=332
  _MARKETBOOKUPDATE._serialized_end=565
# @@protoc_insertion_point(module_scope)
